@@ -3,7 +3,13 @@ from time import sleep
 from typing import Optional
 import pytest
 
-from statsig_python_core import DataStore, StatsigOptions, StatsigUser, Statsig, DataStoreResponse
+from statsig_python_core import (
+    DataStore,
+    StatsigOptions,
+    StatsigUser,
+    Statsig,
+    DataStoreResponse,
+)
 from pytest_httpserver import HTTPServer
 from utils import get_test_data_resource
 
@@ -11,8 +17,9 @@ dcs_content = get_test_data_resource("eval_proj_dcs.json")
 json_data = json.loads(dcs_content)
 
 updated_dcs_json_data = json_data.copy()
-if 'time' in updated_dcs_json_data:
-    updated_dcs_json_data['time'] += 10
+if "time" in updated_dcs_json_data:
+    updated_dcs_json_data["time"] += 10
+
 
 class MockDataStore(DataStore):
     init_called = False
@@ -35,17 +42,16 @@ class MockDataStore(DataStore):
     def get(self, key: str) -> Optional[DataStoreResponse]:
         print(f"Getting value for key: {key}")
         self.get_called_count += 1
-        return DataStoreResponse(
-            result=dcs_content,
-            time=1234567890
-        )
+        return DataStoreResponse(result=dcs_content, time=1234567890)
 
     def set(self, key: str, value: str, time: Optional[int] = None):
         self.content_set = value
         print(f"Setting value for key: {key}")
 
     def support_polling_updates_for(self, key: str) -> bool:
-        print(f"Checking if polling updates are supported for key: {key}: should_poll={self.should_poll}")
+        print(
+            f"Checking if polling updates are supported for key: {key}: should_poll={self.should_poll}"
+        )
         return self.should_poll
 
 
@@ -72,6 +78,7 @@ def statsig_setup(httpserver: HTTPServer):
 
     statsig.shutdown().wait()
 
+
 def test_data_store_usage_get_with_test_param():
     data_store = MockDataStore(test_param="test_param")
     assert data_store.test_param == "test_param"
@@ -99,11 +106,11 @@ def test_data_store_usage_set(statsig_setup):
     statsig.initialize().wait()
 
     gate = statsig.get_feature_gate(user, "test_public")
-    
+
     assert data_store.init_called
     assert gate.details.reason == "Adapter(DataStore):Recognized"
     sleep(1)
-    
+
     gate_after = statsig.get_feature_gate(user, "test_public")
     statsig.flush_events().wait()
 
