@@ -17,7 +17,7 @@ pub(crate) fn get_serializeable_param_stores(
     context: &mut EvaluatorContext,
     options: &ClientInitResponseOptions,
 ) -> SerializeableParamStore {
-    let stores = match &context.spec_store_data.values.param_stores {
+    let stores = match &context.specs_data.param_stores {
         Some(stores) => stores,
         None => return HashMap::new(),
     };
@@ -26,7 +26,7 @@ pub(crate) fn get_serializeable_param_stores(
 
     for (name, store) in stores {
         if should_filter_config_for_app(
-            &store.target_app_ids,
+            store.target_app_ids.as_ref(),
             &context.app_id,
             &options.client_sdk_key,
         ) {
