@@ -121,18 +121,26 @@ impl StatsigHttpIdListsAdapter {
         list_url: &str,
         list_size: u64,
     ) -> Result<String, StatsigErr> {
-        let headers = HashMap::from([("Range".into(), format!("bytes={list_size}-"))]);
-        let query_params = if list_url.starts_with(STATSIG_CDN_URL) {
-            Some(HashMap::from([("range".into(), format!("{list_size}-"))]))
+        let (headers, query_params) = if list_url.starts_with(STATSIG_CDN_URL) {
+            (
+                None,
+                Some(HashMap::from([("range".into(), format!("{list_size}-"))])),
+            )
         } else {
-            None
+            (
+                Some(HashMap::from([(
+                    "Range".into(),
+                    format!("bytes={list_size}-"),
+                )])),
+                None,
+            )
         };
 
         let response = self
             .network
             .get(RequestArgs {
                 url: list_url.to_string(),
-                headers: Some(headers),
+                headers,
                 query_params,
                 ..RequestArgs::new()
             })
@@ -269,12 +277,15 @@ impl StatsigHttpIdListsAdapter {
 
         for (list_name, entry) in new_manifest {
             let (requires_download, range_start) = match curr_manifest.get(&list_name) {
-                Some(current) => (
-                    entry.size > current.size
-                        || entry.creation_time > current.creation_time
-                        || entry.file_id != current.file_id,
-                    current.size,
-                ),
+                Some(current) => {
+                    if entry.creation_time > current.creation_time
+                        || entry.file_id != current.file_id
+                    {
+                        (true, 0u64)
+                    } else {
+                        (entry.size > current.size, current.size)
+                    }
+                }
                 None => (true, 0),
             };
 
