@@ -47,6 +47,10 @@ impl DynamicConfig {
             None => None,
         }
     }
+
+    pub fn get_typed_opt(&self, param_name: &str, fallback: Option<Value>) -> Option<Value> {
+        extract_matching_type(&self.value, param_name, &fallback).or(fallback)
+    }
 }
 
 #[derive(Serialize, Deserialize, Clone)]
@@ -70,6 +74,10 @@ impl Experiment {
             None => None,
         }
     }
+
+    pub fn get_typed_opt(&self, param_name: &str, fallback: Option<Value>) -> Option<Value> {
+        extract_matching_type(&self.value, param_name, &fallback).or(fallback)
+    }
 }
 
 #[derive(Serialize, Deserialize, Clone)]
@@ -110,6 +118,16 @@ impl Layer {
         }
     }
 
+    pub fn get_typed_opt(&self, param_name: &str, fallback: Option<Value>) -> Option<Value> {
+        match extract_matching_type(&self.__value, param_name, &fallback) {
+            Some(value) => {
+                self.log_param_exposure(param_name);
+                Some(value)
+            }
+            None => fallback,
+        }
+    }
+
     pub fn get_raw_value(&self, param_name: &str) -> Option<Value> {
         match self.__value.get(param_name) {
             Some(value) => {
@@ -305,3 +323,21 @@ impl_common_get_methods!(Layer);
 pub enum OverrideAdapterType {
     LocalOverride,
 }
+
+fn extract_matching_type(
+    value: &HashMap<String, Value>,
+    param_name: &str,
+    fallback: &Option<Value>,
+) -> Option<Value> {
+    let found = value.get(param_name)?;
+    match (fallback, found) {
+        (Some(Value::Bool(_)), Value::Bool(_)) => Some(found.clone()),
+        (Some(Value::Number(_)), Value::Number(_)) => Some(found.clone()),
+        (Some(Value::String(_)), Value::String(_)) => Some(found.clone()),
+        (Some(Value::Array(_)), Value::Array(_)) => Some(found.clone()),
+        (Some(Value::Object(_)), Value::Object(_)) => Some(found.clone()),
+        (Some(Value::Null), Value::Null) => Some(found.clone()),
+        (None, value) => Some(value.clone()),
+        _ => None,
+    }
+}
